pub struct Properties { /* private fields */ }Available on crate feature
management only.Expand description
Builder of InstanceProperties.
Implementations
Sourceimpl Properties
impl Properties
Sourcepub const KEY_HOST_NAME: &'static str = "hostname"
pub const KEY_HOST_NAME: &'static str = "hostname"
Instance properties key of host name.
Sourcepub const KEY_LANGUAGE: &'static str = "language"
pub const KEY_LANGUAGE: &'static str = "language"
Instance properties key of programming language.
Sourcepub const KEY_OS_NAME: &'static str = "OS Name"
pub const KEY_OS_NAME: &'static str = "OS Name"
Instance properties key of os name.
Sourcepub const KEY_PROCESS_NO: &'static str = "Process No."
pub const KEY_PROCESS_NO: &'static str = "Process No."
Instance properties key of process number.
Sourceimpl Properties
impl Properties
Sourcepub fn insert(&mut self, key: impl Into<String>, value: impl Into<String>)
pub fn insert(&mut self, key: impl Into<String>, value: impl Into<String>)
Insert key value pair, will not overwrite the original, because multiple values of the same key can exist.
Sourcepub fn update(&mut self, key: &str, value: impl Into<String>)
pub fn update(&mut self, key: &str, value: impl Into<String>)
Overwrite the values, whether there are multiple.
Sourcepub fn insert_os_info(&mut self)
pub fn insert_os_info(&mut self)
Insert the OS system info, such as os name, host name, etc.