pub struct SegmentObject {
pub trace_id: String,
pub trace_segment_id: String,
pub spans: Vec<SpanObject>,
pub service: String,
pub service_instance: String,
pub is_size_limited: bool,
}Expand description
The segment is a collection of spans. It includes all collected spans in a simple one request context, such as a HTTP request process.
We recommend the agent/SDK report all tracked data of one request once for all, such as, typically, such as in Java, one segment represent all tracked operations(spans) of one request context in the same thread. At the same time, in some language there is not a clear concept like golang, it could represent all tracked operations of one request context.
Fields
trace_id: StringA string id represents the whole trace.
trace_segment_id: StringA unique id represents this segment. Other segments could use this id to reference as a child segment.
spans: Vec<SpanObject>Span collections included in this segment.
service: StringService. Represents a set/group of workloads which provide the same behaviours for incoming requests.
The logic name represents the service. This would show as a separate node in the topology. The metrics analyzed from the spans, would be aggregated for this entity as the service level.
service_instance: StringService Instance. Each individual workload in the Service group is known as an instance. Like pods in Kubernetes, it
doesn’t need to be a single OS process, however, if you are using instrument agents, an instance is actually a real OS process.
The logic name represents the service instance. This would show as a separate node in the instance relationship. The metrics analyzed from the spans, would be aggregated for this entity as the service instance level.
is_size_limited: boolWhether the segment includes all tracked spans. In the production environment tracked, some tasks could include too many spans for one request context, such as a batch update for a cache, or an async job. The agent/SDK could optimize or ignore some tracked spans for better performance. In this case, the value should be flagged as TRUE.